@@ -45,6 +45,8 @@ def main():
         if args.bucket_name == 'tasq':
             logger.info('Setting default bucket name gits-active-storage')
             settings.BUCKET = 'gits-active-storage'
+            logger.info('Setting CDN_URL to cdn.tasq.ai')
+            settings.CDN_URL = 'https://cdn.tasq.ai/{object_name}'
         else:
             settings.BUCKET = args.bucket_name
             logger.info(f'Overriding bucket name with {settings.BUCKET}')
